ward

# XMLRésuméLibrary: User Guide

url | Element Reference | year

## Name

ward — A name of a division of a city, town, or county

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `ward` element contains the name of a ward, as needed to deliver mail to an address. A ward is an administrative division a city, and of some English, Scottish, and American counties.

### Parents

`ward` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify a ward. The ward may then be referred to by this identifier.

## See Also

`county`, `prefecture`, `suburb`.

## Examples

    <address>
      <street>Rua Afonso Camargo, 805</street>
      <ward>Santana</ward>
      <city>Guarapuava</city>
      <state>PR</state>
      <postalCode>85070-200</postalCode>
      <country>Brazil</country>
    </address>

url | Element Reference | year